@@ -15,7 +15,7 @@ mod socketio_message;
 // mod socketio_parser;
 mod socketio_upgrade;
 
-pub use socketio::{adapter, SocketIOAdapter, SocketIOSocket as SocketIO, broadcast};
-pub use socketio_context::SocketIOContext;
-pub use socketio_upgrade::handle_io;
 pub use rooms::{get_sockets_for_room, get_sockets_number_for_room, print_sockets_for_room};
+pub use socketio::{adapter, broadcast, SocketIOAdapter, SocketIOSocket as SocketIO};
+pub use socketio_context::SocketIOContext;
+pub use socketio_upgrade::{handle_io, handle_io_with_capacity};
